==> nextcloud-31.0.6.tar.bz2: nextcloud/apps/circles/l10n/es_AR.js <==
OC.L10N.register(
    "circles",
    {
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Password protected" : "Protegido con contraseña",
    "Hidden" : "Oculto",
    "Local" : "Local",
    "Root" : "Raíz",
    "Federated" : "Federado",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s ha compartido »%s« con usted.",
    "Password to access »%1$s« shared to you by %2$s" : "Contraseña para acceder a »%1$s« compartido con usted por %2$s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "It is protected with the following password:" : "Está protegido con la siguiente contraseña:",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "Files" : "Archivo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "This member does not exist" : "Este miembro no existe",
    "You are already a member of this circle" : "Usted ya es un miembro de este círculo",
    "You have been blocked from this circle" : "Usted ha sido bloqueado de este círculo",
    "Accept" : "Aceptar",
    "%s" : "%s",
    "No files in here" : "No hay archivos aqui",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.2.tar.bz2: nextcloud/apps/circles/l10n/es_AR.js <==
OC.L10N.register(
    "circles",
    {
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Password protected" : "Protegido con contraseña",
    "Hidden" : "Oculto",
    "Local" : "Local",
    "Root" : "Raíz",
    "Federated" : "Federado",
    "Contact" : "Contacto",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s ha compartido »%s« con usted.",
    "Password to access »%1$s« shared to you by %2$s" : "Contraseña para acceder a »%1$s« compartido con usted por %2$s",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "It is protected with the following password:" : "Está protegido con la siguiente contraseña:",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "Files" : "Archivo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "This member does not exist" : "Este miembro no existe",
    "Accept" : "Aceptar",
    "%s" : "%s",
    "Open %s" : "Abrir %s",
    "Try again" : "Inténtalo de nuevo",
    "Loading…" : "Cargando…",
    "No files in here" : "No hay archivos aqui",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "You are already a member of this circle" : "Usted ya es un miembro de este círculo",
    "You have been blocked from this circle" : "Usted ha sido bloqueado de este círculo"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
